@@ -1,5 +1,5 @@
-from .fields import ImageRatioField, ImageCropField
 from .admin import ImageCroppingMixin
+from .fields import ImageCropField, ImageRatioField
 from .widgets import ImageCropWidget
 
-__version__ = '1.4.0'
+__version__ = '1.5.0'
