@@ -1,17 +1,17 @@
-from __future__ import unicode_literals
-from django.db import models
 from django import forms
+from django.db import models
 from django.db.models import signals
-from .widgets import ImageCropWidget
-from .utils import max_cropping
+
 from .config import settings
+from .utils import get_backend, max_cropping
+from .widgets import ImageCropWidget
 
 
 class ImageCropField(models.ImageField):
     def formfield(self, **kwargs):
         defaults = {'widget': ImageCropWidget}
         defaults.update(kwargs)
-        return super(ImageCropField, self).formfield(**defaults)
+        return super().formfield(**defaults)
 
     def south_field_triple(self):  # pragma: no cover
         """
@@ -33,13 +33,14 @@ class ImageRatioField(models.CharField):
             self.image_field, self.image_fk_field = image_field.split('__')
         else:
             self.image_field, self.image_fk_field = image_field, None
-
         self.width, self.height = list(map(int, size.split('x')))
         self.free_crop = free_crop
         self.adapt_rotation = adapt_rotation
         self.allow_fullsize = allow_fullsize
         self.size_warning = size_warning
         self.hide_image_field = hide_image_field
+        self.box_max_width = settings.IMAGE_CROPPING_THUMB_SIZE[0]
+        self.box_max_height = settings.IMAGE_CROPPING_THUMB_SIZE[1]
         field_kwargs = {
             'max_length': 255,
             'default': '',
@@ -47,7 +48,7 @@ class ImageRatioField(models.CharField):
             'verbose_name': verbose_name,
             'help_text': help_text
         }
-        super(ImageRatioField, self).__init__(**field_kwargs)
+        super().__init__(**field_kwargs)
 
     def deconstruct(self):  # pragma: no cover
         """
@@ -71,23 +72,23 @@ class ImageRatioField(models.CharField):
         }
         return self.name, 'image_cropping.fields.ImageRatioField', args, kwargs
 
-    def contribute_to_class(self, cls, name):
-        super(ImageRatioField, self).contribute_to_class(cls, name)
-        # attach a list of fields that are referenced by the ImageRatioField
-        # so we can set the correct widget in the ModelAdmin
-        if not hasattr(cls, 'crop_fields'):
-            cls.add_to_class('crop_fields', {})
-        cls.crop_fields[self.image_field] = {
-            'fk_field': self.image_fk_field,
-            'hidden': self.hide_image_field,
-        }
-
-        # attach ratiofields to cls
-        if not hasattr(cls, 'ratio_fields'):
-            cls.add_to_class('ratio_fields', [])
-        cls.ratio_fields.append(name)
-
+    def contribute_to_class(self, cls, name, **kwargs):
+        super().contribute_to_class(cls, name, **kwargs)
         if not cls._meta.abstract:
+            # attach a list of fields that are referenced by the ImageRatioField
+            # so we can set the correct widget in the ModelAdmin
+            if not hasattr(cls, 'crop_fields'):
+                cls.add_to_class('crop_fields', {})
+            cls.crop_fields[self.image_field] = {
+                'fk_field': self.image_fk_field,
+                'hidden': self.hide_image_field,
+            }
+
+            # attach ratiofields to cls
+            if not hasattr(cls, 'ratio_fields'):
+                cls.add_to_class('ratio_fields', [])
+            cls.ratio_fields.append(name)
+
             signals.pre_save.connect(self.initial_cropping, sender=cls)
 
     def initial_cropping(self, sender, instance, *args, **kwargs):
@@ -106,10 +107,20 @@ class ImageRatioField(models.CharField):
                 continue
 
             # calculate initial cropping
-            box = max_cropping(ratiofield.width, ratiofield.height,
-                               image.width, image.height,
-                               free_crop=ratiofield.free_crop)
-            box = ','.join(map(lambda i: str(i), box))
+            width, height = (100, 100)
+            try:
+                width, height = (image.width, image.height)
+            except AttributeError:
+                width, height = get_backend().get_size(image)
+
+            try:
+                # handle corrupt or accidentally removed images
+                box = max_cropping(ratiofield.width, ratiofield.height,
+                                   width, height,
+                                   free_crop=ratiofield.free_crop)
+                box = ','.join(map(lambda i: str(i), box))
+            except IOError:
+                box = ''
             setattr(instance, ratiofieldname, box)
 
     def formfield(self, *args, **kwargs):
@@ -118,15 +129,18 @@ class ImageRatioField(models.CharField):
         kwargs['widget'] = forms.TextInput(attrs={
             'data-min-width': self.width,
             'data-min-height': self.height,
-            'data-ratio': ratio,
+            'data-box-max-width': self.box_max_width,
+            'data-box-max-height': self.box_max_height,
+            'data-ratio': str(ratio),
             'data-image-field': self.image_field,
             'data-my-name': self.name,
+            'data-jquery-url': settings.IMAGE_CROPPING_JQUERY_URL,
             'data-adapt-rotation': str(self.adapt_rotation).lower(),
             'data-allow-fullsize': str(self.allow_fullsize).lower(),
             'data-size-warning': str(self.size_warning).lower(),
             'class': 'image-ratio',
         })
-        return super(ImageRatioField, self).formfield(*args, **kwargs)
+        return super().formfield(*args, **kwargs)
 
     def south_field_triple(self):  # pragma: no cover
         """
